@@ -1,7 +1,7 @@
-use bitvec::prelude::*;
 use numpy::PyReadonlyArrayDyn;
 use pyo3::exceptions::PyTypeError;
 use pyo3::prelude::*;
+use rayon::prelude::*;
 
 /// count_ones(arr)
 /// --
@@ -21,8 +21,12 @@ fn count_ones(arr: PyReadonlyArrayDyn<u8>) -> PyResult<usize> {
         Err(error) => return Err(PyTypeError::new_err(error)),
     };
 
-    let bits = BitSlice::<_, Lsb0>::from_slice(&arr);
-    Ok(bits.count_ones())
+    let bit_count = arr
+        .into_par_iter()
+        .map(|elem| elem.count_ones() as usize)
+        .sum::<usize>();
+
+    Ok(bit_count)
 }
 
 #[pymodule]
